@@ -1,12 +1,12 @@
 // Symphonia
-// Copyright (c) 2020 The Project Symphonia Developers.
+// Copyright (c) 2019-2021 The Project Symphonia Developers.
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
 use symphonia_core::errors::Result;
-use symphonia_core::io::ByteStream;
+use symphonia_core::io::ReadBytes;
 
 use crate::atoms::{Atom, AtomHeader};
 
@@ -22,7 +22,7 @@ impl Atom for CttsAtom {
         self.header
     }
 
-    fn read<B: ByteStream>(_reader: &mut B, _header: AtomHeader) -> Result<Self> {
+    fn read<B: ReadBytes>(_reader: &mut B, _header: AtomHeader) -> Result<Self> {
         todo!()
     }
 }
\ No newline at end of file
