@@ -1,12 +1,12 @@
 // Symphonia
-// Copyright (c) 2020 The Project Symphonia Developers.
+// Copyright (c) 2019-2021 The Project Symphonia Developers.
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
 use symphonia_core::errors::{Result, decode_error};
-use symphonia_core::io::ByteStream;
+use symphonia_core::io::ReadBytes;
 
 use crate::atoms::{Atom, AtomHeader};
 use crate::fourcc::FourCc;
@@ -21,10 +21,10 @@ pub struct FtypAtom {
 }
 
 impl Atom for FtypAtom {
-    fn read<B: ByteStream>(reader: &mut B, header: AtomHeader) -> Result<Self> {
+    fn read<B: ReadBytes>(reader: &mut B, header: AtomHeader) -> Result<Self> {
         // The Ftyp atom must be a multiple of 4 since it only stores FourCCs.
         if header.data_len & 0x3 != 0 {
-            return decode_error("invalid ftyp data length");
+            return decode_error("isomp4: invalid ftyp data length");
         }
     
         // Major
