@@ -1,12 +1,12 @@
 // Symphonia
-// Copyright (c) 2020 The Project Symphonia Developers.
+// Copyright (c) 2019-2021 The Project Symphonia Developers.
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
 use symphonia_core::errors::{Result, decode_error};
-use symphonia_core::io::ByteStream;
+use symphonia_core::io::ReadBytes;
 
 use crate::atoms::{Atom, AtomHeader};
 
@@ -24,7 +24,7 @@ impl Atom for MehdAtom {
         self.header
     }
 
-    fn read<B: ByteStream>(reader: &mut B, header: AtomHeader) -> Result<Self> {
+    fn read<B: ReadBytes>(reader: &mut B, header: AtomHeader) -> Result<Self> {
         let (version, _) = AtomHeader::read_extra(reader)?;
 
         let fragment_duration = match version {
@@ -35,7 +35,7 @@ impl Atom for MehdAtom {
                 reader.read_be_u64()?
             }
             _ => {
-                return decode_error("invalid mehd version");
+                return decode_error("isomp4: invalid mehd version");
             }
         };
 
