@@ -1,13 +1,13 @@
 // Symphonia
-// Copyright (c) 2020 The Project Symphonia Developers.
+// Copyright (c) 2019-2021 The Project Symphonia Developers.
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
 use symphonia_core::errors::Result;
-use symphonia_core::io::ByteStream;
-use symphonia_core::meta::MetadataQueue;
+use symphonia_core::io::ReadBytes;
+use symphonia_core::meta::MetadataLog;
 
 use crate::atoms::{Atom, AtomHeader, AtomIterator, AtomType, MetaAtom};
 
@@ -21,10 +21,10 @@ pub struct UdtaAtom {
 }
 
 impl UdtaAtom {
-    /// Consume any metadata, and push it onto provided `MetadataQueue`.
-    pub fn take_metadata(&mut self, queue: &mut MetadataQueue) {
+    /// Consume any metadata, and push it onto provided `MetadataLog`.
+    pub fn take_metadata(&mut self, log: &mut MetadataLog) {
         if let Some(meta) = self.meta.take() {
-            meta.take_metadata(queue);
+            meta.take_metadata(log)
         }
     }
 }
@@ -34,7 +34,8 @@ impl Atom for UdtaAtom {
         self.header
     }
 
-    fn read<B: ByteStream>(reader: &mut B, header: AtomHeader) -> Result<Self> {
+    #[allow(clippy::single_match)]
+    fn read<B: ReadBytes>(reader: &mut B, header: AtomHeader) -> Result<Self> {
         let mut iter = AtomIterator::new(reader, header);
         
         let mut meta = None;
