@@ -1,5 +1,5 @@
 // Symphonia
-// Copyright (c) 2020 The Project Symphonia Developers.
+// Copyright (c) 2019-2021 The Project Symphonia Developers.
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -11,8 +11,8 @@ use symphonia_core::{errors::end_of_stream_error, support_format};
 use symphonia_core::codecs::{CodecParameters, CODEC_TYPE_AAC};
 use symphonia_core::errors::{Result, SeekErrorKind, decode_error, seek_error, unsupported_error};
 use symphonia_core::formats::prelude::*;
-use symphonia_core::io::{ByteStream, MediaSource, MediaSourceStream};
-use symphonia_core::meta::MetadataQueue;
+use symphonia_core::io::{ReadBytes, MediaSource, MediaSourceStream};
+use symphonia_core::meta::{Metadata, MetadataLog};
 use symphonia_core::probe::{Descriptor, Instantiate, QueryDescriptor};
 use symphonia_core::units::Time;
 
@@ -40,8 +40,8 @@ pub struct TrackState {
 
 impl TrackState {
 
+    #[allow(clippy::single_match)]
     pub fn new(track_num: u32, trak: &TrakAtom) -> Self {
-
         let mut codec_params = CodecParameters::new();
 
         codec_params.with_time_base(TimeBase::new(1, trak.mdia.mdhd.timescale));
@@ -52,6 +52,7 @@ impl TrackState {
             SampleDescription::Mp4a(ref mp4a) => {
                 codec_params
                     .for_codec(CODEC_TYPE_AAC)
+                    .with_n_frames(trak.tkhd.duration)
                     .with_sample_rate(
                         mp4a.sound_desc.sample_rate as u32)
                     .with_extra_data(
@@ -105,7 +106,7 @@ pub struct IsoMp4Reader {
     iter: AtomIterator<MediaSourceStream>,
     tracks: Vec<Track>,
     cues: Vec<Cue>,
-    metadata: MetadataQueue,
+    metadata: MetadataLog,
     /// Segments of the movie. Sorted in ascending order by sequence number.
     segs: Vec<Box<dyn StreamSegment>>,
     /// State tracker for each track.
@@ -146,7 +147,6 @@ impl IsoMp4Reader {
                         {
                             // Earliest is less than or equal to the track's next sample presentation
                             // time. No need to update earliest.
-                            ()
                         }
                         _ => {
                             // Earliest was either None, or greater than the track's next sample
@@ -225,7 +225,7 @@ impl IsoMp4Reader {
                         let last_seg = self.segs.last().unwrap();
 
                         // Create a new segment for the moof atom.
-                        let seg = MoofSegment::new(moof, mvex.clone(), last_seg);
+                        let seg = MoofSegment::new(moof, mvex.clone(), last_seg.as_ref());
 
                         // Segments should have a monotonic sequence number.
                         if seg.sequence_num() <= last_seg.sequence_num() {
@@ -237,7 +237,7 @@ impl IsoMp4Reader {
                     }
                     else {
                         // TODO: This is a fatal error.
-                        return decode_error("moof atom present without mvex atom");
+                        return decode_error("isomp4: moof atom present without mvex atom");
                     }
                 },
                 _ => {
@@ -370,7 +370,7 @@ impl FormatReader for IsoMp4Reader {
             None
         };
 
-        let mut metadata = MetadataQueue::default();
+        let mut metadata = MetadataLog::default();
 
         // Parse all atoms if the stream is seekable, otherwise parse all atoms up-to the mdat atom.
         let mut iter = AtomIterator::new_root(mss, total_len);
@@ -424,7 +424,7 @@ impl FormatReader for IsoMp4Reader {
                     }
                 }
                 AtomType::Meta => {
-                    // Read the metadata atom and queue it.
+                    // Read the metadata atom and append it to the log.
                     let meta = iter.read_atom::<MetaAtom>()?;
                     meta.take_metadata(&mut metadata);
                 }
@@ -437,11 +437,11 @@ impl FormatReader for IsoMp4Reader {
         }
 
         if ftyp.is_none() {
-            return unsupported_error("missing ftyp atom");
+            return unsupported_error("isomp4: missing ftyp atom");
         }
 
         if moov.is_none() {
-            return unsupported_error("missing moov atom");
+            return unsupported_error("isomp4: missing moov atom");
         }
 
         // If the stream was seekable, then all atoms in the stream were scanned. Seek back to the
@@ -480,7 +480,7 @@ impl FormatReader for IsoMp4Reader {
 
         // A Movie Extends (mvex) atom is required to support segmented streams. If the mvex atom is
         // present, wrap it in an Arc so it can be shared amongst all segments.
-        let mvex = moov.mvex.take().map(|m| Arc::new(m));
+        let mvex = moov.mvex.take().map(Arc::new);
 
         let segs: Vec<Box<dyn StreamSegment>> = vec![ Box::new(MoovSegment::new(moov)) ];
 
@@ -530,7 +530,7 @@ impl FormatReader for IsoMp4Reader {
             else {
                 // The stream is not seekable and the desired seek position falls outside the lower
                 // bound of the buffer cache. This sample cannot be read.
-                return decode_error("packet out-of-bounds for a non-seekable stream");
+                return decode_error("isomp4: packet out-of-bounds for a non-seekable stream");
             }
         }
 
@@ -542,8 +542,8 @@ impl FormatReader for IsoMp4Reader {
         ))
     }
 
-    fn metadata(&self) -> &MetadataQueue {
-        &self.metadata
+    fn metadata(&mut self) -> Metadata<'_> {
+        self.metadata.metadata()
     }
 
     fn cues(&self) -> &[Cue] {
