@@ -1,5 +1,5 @@
 // Symphonia
-// Copyright (c) 2020 The Project Symphonia Developers.
+// Copyright (c) 2019-2021 The Project Symphonia Developers.
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -63,7 +63,7 @@ pub struct MoofSegment {
 
 impl MoofSegment {
     /// Instantiate a new segment from a `MoofAtom`.
-    pub fn new(moof: MoofAtom, mvex: Arc<MvexAtom>, last: &Box<dyn StreamSegment>) -> MoofSegment {
+    pub fn new(moof: MoofAtom, mvex: Arc<MvexAtom>, last: &dyn StreamSegment) -> MoofSegment {
         let mut seq = Vec::new();
 
         // Calculate the sequence information for each track of this segment.
@@ -265,7 +265,7 @@ impl StreamSegment for MoofSegment {
             // Get or calculate the total size of the track fragment run.
             let trun_size = if trun.is_sample_size_present() {
                 // The size of the entire track fragment run is known.
-                u64::from(trun.total_sample_size)
+                trun.total_sample_size
             }
             else {
                 let size = traf.tfhd.default_sample_size.unwrap_or(
@@ -278,7 +278,7 @@ impl StreamSegment for MoofSegment {
             trun_offset += trun_size;
         }
 
-        decode_error("invalid sample index")
+        decode_error("isomp4: invalid sample index")
     }
 
     fn track_sample_range(&self, track_num: u32) -> (u32, u32) {
@@ -307,7 +307,7 @@ fn get_chunk_offset(
             Ok(Some(u64::from(*offset)))
         }
         else {
-            decode_error("missing stco entry")
+            decode_error("isomp4: missing stco entry")
         }
     }
     else if let Some(co64) = co64.as_ref() {
@@ -316,12 +316,12 @@ fn get_chunk_offset(
             Ok(Some(*offset))
         }
         else {
-            decode_error("missing co64 entry")
+            decode_error("isomp4: missing co64 entry")
         }
     }
     else {
         // This should never happen because it is mandatory to have either a stco or co64 atom.
-        decode_error("missing stco or co64 atom")
+        decode_error("isomp4: missing stco or co64 atom")
     }
 }
 
@@ -392,7 +392,7 @@ impl StreamSegment for MoovSegment {
         let chunk_in_stream = group.first_chunk + chunk_in_group;
 
         // Get the byte position of the first sample of the chunk containing the sample.
-        let base_pos = get_chunk_offset(&stco, &co64, chunk_in_stream as usize)?.unwrap();
+        let base_pos = get_chunk_offset(stco, co64, chunk_in_stream as usize)?.unwrap();
 
         // Determine the absolute sample byte position if requested by calculating the offset of
         // the sample from the base position of the chunk.
@@ -415,7 +415,7 @@ impl StreamSegment for MoovSegment {
                         samples.iter().map(|&size| u64::from(size)).sum()
                     }
                     else {
-                        return decode_error("missing one or more stsz entries");
+                        return decode_error("isomp4: missing one or more stsz entries");
                     }
                 }
             };
@@ -434,7 +434,7 @@ impl StreamSegment for MoovSegment {
                     *size
                 }
                 else {
-                    return decode_error("missing stsz entry");
+                    return decode_error("isomp4: missing stsz entry");
                 }
             }
         };
